@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import pickle
 from functools import partial
 from operator import add
@@ -13,16 +11,25 @@ from dask.array.ufunc import da_frompyfunc
 from dask.array.utils import assert_eq
 from dask.base import tokenize
 
+DISCLAIMER = """
+This docstring was copied from numpy.{name}.
 
-def test_ufunc_meta():
-    assert da.log.__name__ == "log"
-    assert da.log.__doc__.replace("  # doctest: +SKIP", "") == np.log.__doc__
+Some inconsistencies with the Dask version may exist.
+"""
 
-    assert da.modf.__name__ == "modf"
-    assert da.modf.__doc__.replace("  # doctest: +SKIP", "") == np.modf.__doc__
 
-    assert da.frexp.__name__ == "frexp"
-    assert da.frexp.__doc__.replace("  # doctest: +SKIP", "") == np.frexp.__doc__
+@pytest.mark.parametrize("name", ["log", "modf", "frexp"])
+def test_ufunc_meta(name):
+    disclaimer = DISCLAIMER.format(name=name)
+    skip_test = "  # doctest: +SKIP"
+    ufunc = getattr(da, name)
+    assert ufunc.__name__ == name
+    assert disclaimer in ufunc.__doc__
+
+    assert (
+        ufunc.__doc__.replace(disclaimer, "").replace(skip_test, "")
+        == getattr(np, name).__doc__
+    )
 
 
 def test_ufunc():
@@ -467,3 +474,19 @@ def test_divmod():
     expected = divmod(arr1, arr2)
     assert_eq(result[0], expected[0])
     assert_eq(result[1], expected[1])
+
+
+@pytest.mark.parametrize("dt", ["float64", "float32", "int32", "int64"])
+def test_dtype_kwarg(dt):
+    arr1 = np.array([1, 2, 3])
+    arr2 = np.array([4, 5, 6])
+
+    darr1 = da.from_array(arr1)
+    darr2 = da.from_array(arr2)
+
+    expected = np.add(arr1, arr2, dtype=dt)
+    result = np.add(darr1, darr2, dtype=dt)
+    assert_eq(expected, result)
+
+    result = da.add(darr1, darr2, dtype=dt)
+    assert_eq(expected, result)
