@@ -8,13 +8,7 @@ from ..base import tokenize
 from ..layers import BlockwiseCreateArray
 from ..utils import funcname
 from .core import Array, normalize_chunks
-from .utils import (
-    empty_like_safe,
-    full_like_safe,
-    meta_from_array,
-    ones_like_safe,
-    zeros_like_safe,
-)
+from .utils import meta_from_array
 
 
 def _parse_wrap_args(func, args, kwargs, shape):
@@ -180,9 +174,9 @@ def broadcast_trick(func):
     return inner
 
 
-ones = w(broadcast_trick(ones_like_safe), dtype="f8")
-zeros = w(broadcast_trick(zeros_like_safe), dtype="f8")
-empty = w(broadcast_trick(empty_like_safe), dtype="f8")
+ones = w(broadcast_trick(np.ones_like), dtype="f8")
+zeros = w(broadcast_trick(np.zeros_like), dtype="f8")
+empty = w(broadcast_trick(np.empty_like), dtype="f8")
 
 
 w_like = wrap(wrap_func_like_safe)
@@ -193,7 +187,7 @@ empty_like = w_like(np.empty, func_like=np.empty_like)
 
 # full and full_like require special casing due to argument check on fill_value
 # Generate wrapped functions only once
-_full = w(broadcast_trick(full_like_safe))
+_full = w(broadcast_trick(np.full_like))
 _full_like = w_like(np.full, func_like=np.full_like)
 
 # workaround for numpy doctest failure: https://github.com/numpy/numpy/pull/17472
