@@ -86,7 +86,7 @@ class CSVFunctionWrapper:
     def __call__(self, part):
 
         # Part will be a 3-element tuple
-        block, path, is_first = part
+        block, path, is_first, is_last = part
 
         # Construct `path_info`
         if path is not None:
@@ -105,6 +105,8 @@ class CSVFunctionWrapper:
         if not is_first:
             write_header = True
             rest_kwargs.pop("skiprows", None)
+        if not is_last:
+            rest_kwargs.pop("skipfooter", None)
 
         # Deal with column projection
         columns = self.full_columns
@@ -179,8 +181,6 @@ def pandas_read_text(
 
     if enforce and columns and (list(df.columns) != list(columns)):
         raise ValueError("Columns do not match", df.columns, columns)
-    elif columns:
-        df.columns = columns
     if path:
         colname, path, paths = path
         code = paths.index(path)
@@ -348,6 +348,7 @@ def text_blocks_to_pandas(
     blocks = tuple(flatten(block_lists))
     # Create mask of first blocks from nested block_lists
     is_first = tuple(block_mask(block_lists))
+    is_last = tuple(block_mask_last(block_lists))
 
     if path:
         colname, path_converter = path
@@ -370,13 +371,7 @@ def text_blocks_to_pandas(
     parts = []
     colname, paths = path or (None, None)
     for i in range(len(blocks)):
-        parts.append(
-            [
-                blocks[i],
-                paths[i] if paths else None,
-                is_first[i],
-            ]
-        )
+        parts.append([blocks[i], paths[i] if paths else None, is_first[i], is_last[i]])
 
     # Create Blockwise layer
     label = "read-csv-"
@@ -418,6 +413,21 @@ def block_mask(block_lists):
         yield from (False for _ in block[1:])
 
 
+def block_mask_last(block_lists):
+    """
+    Yields a flat iterable of booleans to mark the last element of the
+    nested input ``block_lists`` in a flattened output.
+
+    >>> list(block_mask_last([[1, 2], [3, 4], [5]]))
+    [False, True, False, True, True]
+    """
+    for block in block_lists:
+        if not block:
+            continue
+        yield from (False for _ in block[:-1])
+        yield True
+
+
 def auto_blocksize(total_memory, cpu_count):
     memory_factor = 10
     blocksize = int(total_memory // cpu_count / memory_factor)
@@ -578,8 +588,10 @@ def read_pandas(
     header = b"" if header is None else parts[firstrow] + b_lineterminator
 
     # Use sample to infer dtypes and check for presence of include_path_column
+    head_kwargs = kwargs.copy()
+    head_kwargs.pop("skipfooter", None)
     try:
-        head = reader(BytesIO(b_sample), nrows=sample_rows, **kwargs)
+        head = reader(BytesIO(b_sample), nrows=sample_rows, **head_kwargs)
     except pd.errors.ParserError as e:
         if "EOF" in str(e):
             raise ValueError(
@@ -923,7 +935,9 @@ def to_csv(
         if scheduler is not None and compute_kwargs.get("scheduler") is None:
             compute_kwargs["scheduler"] = scheduler
 
-        delayed(values).compute(**compute_kwargs)
+        import dask
+
+        dask.compute(*values, **compute_kwargs)
         return [f.path for f in files]
     else:
         return values
