@@ -640,7 +640,13 @@ def test_set_index_interpolate(engine):
 
     d1 = d.set_index("x", npartitions=3)
     assert d1.npartitions == 3
-    assert set(d1.divisions) == set([1, 2, 4])
+    if engine == "cudf":
+        # cuDF has to use "linear" interpolation as "nearest" interpolation
+        # is not supported by CuPy. The result for d1.divisions is different
+        # in this case.
+        assert set(d1.divisions) == set([1, 2, 3, 4])
+    else:
+        assert set(d1.divisions) == set([1, 2, 4])
 
     d2 = d.set_index("y", npartitions=3)
     assert d2.divisions[0] == 1.0
