@@ -1,15 +1,12 @@
-from __future__ import absolute_import, division, print_function
-
 from collections import namedtuple
 from itertools import starmap
-from timeit import default_timer
+from multiprocessing import Pipe, Process, current_process
 from time import sleep
-from multiprocessing import Process, Pipe, current_process
+from timeit import default_timer
 
 from ..callbacks import Callback
 from ..utils import import_required
 
-
 # Stores execution data for each task
 TaskData = namedtuple(
     "TaskData", ("key", "task", "start_time", "end_time", "worker_id")
@@ -31,23 +28,24 @@ class Profiler(Callback):
 
     >>> from operator import add, mul
     >>> from dask.threaded import get
+    >>> from dask.diagnostics import Profiler
     >>> dsk = {'x': 1, 'y': (add, 'x', 10), 'z': (mul, 'y', 2)}
     >>> with Profiler() as prof:
     ...     get(dsk, 'z')
     22
 
-    >>> prof.results  # doctest: +SKIP
-    [('y', (add, 'x', 10), 1435352238.48039, 1435352238.480655, 140285575100160),
-     ('z', (mul, 'y', 2), 1435352238.480657, 1435352238.480803, 140285566707456)]
+    >>> prof.results        # doctest: +SKIP
+    [TaskData(key='y', task=(add, 'x', 10), start_time=..., end_time=..., worker_id=...),
+     TaskData(key='z', task=(mul, 'y', 2), start_time=..., end_time=..., worker_id=...)]
 
     These results can be visualized in a bokeh plot using the ``visualize``
     method. Note that this requires bokeh to be installed.
 
-    >>> prof.visualize() # doctest: +SKIP
+    >>> prof.visualize()    # doctest: +SKIP
 
     You can activate the profiler globally
 
-    >>> prof.register()  # doctest: +SKIP
+    >>> prof.register()
 
     If you use the profiler globally you will need to clear out old results
     manually.
@@ -63,7 +61,7 @@ class Profiler(Callback):
 
     def __enter__(self):
         self.clear()
-        return super(Profiler, self).__enter__()
+        return super().__enter__()
 
     def _start(self, dsk):
         self._dsk.update(dsk)
@@ -121,7 +119,7 @@ class ResourceProfiler(Callback):
     >>> from operator import add, mul
     >>> from dask.threaded import get
     >>> dsk = {'x': 1, 'y': (add, 'x', 10), 'z': (mul, 'y', 2)}
-    >>> with ResourceProfiler() as prof:  # doctest: +SKIP
+    >>> with ResourceProfiler() as prof:
     ...     get(dsk, 'z')
     22
 
@@ -132,12 +130,12 @@ class ResourceProfiler(Callback):
 
     You can activate the profiler globally
 
-    >>> prof.register()  # doctest: +SKIP
+    >>> prof.register()
 
     If you use the profiler globally you will need to clear out old results
     manually.
 
-    >>> prof.clear()  # doctest: +SKIP
+    >>> prof.clear()
 
     Note that when used as a context manager data will be collected throughout
     the duration of the enclosed block. In contrast, when registered globally
@@ -168,13 +166,13 @@ class ResourceProfiler(Callback):
         self._entered = True
         self.clear()
         self._start_collect()
-        return super(ResourceProfiler, self).__enter__()
+        return super().__enter__()
 
     def __exit__(self, *args):
         self._entered = False
         self._stop_collect()
         self.close()
-        super(ResourceProfiler, self).__exit__(*args)
+        super().__exit__(*args)
 
     def _start(self, dsk):
         self._start_collect()
@@ -215,7 +213,7 @@ class _Tracker(Process):
     """Background process for tracking resource usage"""
 
     def __init__(self, dt=1):
-        Process.__init__(self)
+        super().__init__()
         self.daemon = True
         self.dt = dt
         self.parent_pid = current_process().pid
@@ -291,23 +289,25 @@ class CacheProfiler(Callback):
 
     >>> from operator import add, mul
     >>> from dask.threaded import get
+    >>> from dask.diagnostics import CacheProfiler
     >>> dsk = {'x': 1, 'y': (add, 'x', 10), 'z': (mul, 'y', 2)}
     >>> with CacheProfiler() as prof:
     ...     get(dsk, 'z')
     22
 
     >>> prof.results    # doctest: +SKIP
-    [CacheData('y', (add, 'x', 10), 1, 1435352238.48039, 1435352238.480655),
-     CacheData('z', (mul, 'y', 2), 1, 1435352238.480657, 1435352238.480803)]
+    [CacheData(key='y', task=(add, 'x', 10), metric=1, cache_time=..., free_time=...),
+     CacheData(key='z', task=(mul, 'y', 2), metric=1, cache_time=..., free_time=...)]
 
     The default is to count each task (``metric`` is 1 for all tasks). Other
     functions may used as a metric instead through the ``metric`` keyword. For
     example, the ``nbytes`` function found in ``cachey`` can be used to measure
     the number of bytes in the cache.
 
-    >>> from cachey import nbytes    # doctest: +SKIP
-    >>> with CacheProfiler(metric=nbytes) as prof:  # doctest: +SKIP
+    >>> from cachey import nbytes
+    >>> with CacheProfiler(metric=nbytes) as prof:
     ...     get(dsk, 'z')
+    22
 
     The profiling results can be visualized in a bokeh plot using the
     ``visualize`` method. Note that this requires bokeh to be installed.
@@ -316,7 +316,7 @@ class CacheProfiler(Callback):
 
     You can activate the profiler globally
 
-    >>> prof.register()  # doctest: +SKIP
+    >>> prof.register()
 
     If you use the profiler globally you will need to clear out old results
     manually.
@@ -337,7 +337,7 @@ class CacheProfiler(Callback):
 
     def __enter__(self):
         self.clear()
-        return super(CacheProfiler, self).__enter__()
+        return super().__enter__()
 
     def _start(self, dsk):
         self._dsk.update(dsk)
@@ -347,7 +347,7 @@ class CacheProfiler(Callback):
     def _posttask(self, key, value, dsk, state, id):
         t = default_timer()
         self._cache[key] = (self._metric(value), t)
-        for k in state["released"].intersection(self._cache):
+        for k in state["released"] & self._cache.keys():
             metric, start = self._cache.pop(k)
             self.results.append(CacheData(k, dsk[k], metric, start, t))
 
